@@ -1,4 +1,4 @@
-#!D:\bld\digital_rf_1590786708817\_h_env\python.exe
+#!D:\bld\digital_rf_1590951629982\_h_env\python.exe
 # ----------------------------------------------------------------------------
 # Copyright (c) 2017 Massachusetts Institute of Technology (MIT)
 # All rights reserved.
@@ -22,7 +22,6 @@
 import calendar
 import getopt
 import os
-import string
 import sys
 import time
 import traceback
@@ -438,13 +437,11 @@ def histogram_plot(data, sfreq, toffset, bins, log_scale, title):
     fig = plt.figure()
     ax = fig.add_subplot(1, 1, 1)
     ax.hist(np.real(data), bins, log=log_scale, histtype="bar", color=["green"])
-    ax.hold(True)
     ax.hist(np.imag(data), bins, log=log_scale, histtype="bar", color=["blue"])
     ax.grid(True)
     ax.set_xlabel("adc value")
     ax.set_ylabel("frequency")
     ax.set_title(title)
-    ax.hold(False)
 
     return fig
 
@@ -1111,7 +1108,7 @@ if __name__ == "__main__":
         elif opt in ("-p"):
             plot_type = val
         elif opt in ("-c"):
-            sp = string.split(val, ":")
+            sp = val.split(":")
             if len(sp) > 0:
                 channel = sp[0]
             if len(sp) > 1:
@@ -1125,7 +1122,7 @@ if __name__ == "__main__":
             print(atime)
 
         elif opt in ("-r"):
-            sp = string.split(val, ":")
+            sp = val.split(":")
 
             if len(sp) > 0:
                 start_sample = int(sp[0])
@@ -1145,7 +1142,7 @@ if __name__ == "__main__":
                 sys.exit()
 
         elif opt in ("-z"):
-            zl, zh = string.split(val, ":")
+            zl, zh = val.split(":")
             zscale = (float(zl), float(zh))
 
         elif opt in ("-b"):
@@ -1157,7 +1154,7 @@ if __name__ == "__main__":
         elif opt in ("-d"):
             detrend = True
         elif opt in ("-m"):
-            cl, bl = string.split(val, ":")
+            cl, bl = val.split(":")
             msl_code_length = int(cl)
             msl_baud_length = int(bl)
 
